# encoding: utf-8
require 'spec_helper'

describe Dataset do
  context "searchable" do
  
    describe "collapse" do
    
      context "given an invalid collapse" do
        it "should ignore number" do  
          Dataset.collapse(123).attributes[:collapse].should be_nil
        end
      
        it "should ignore string" do  
          Dataset.collapse("invalid").attributes[:collapse].should be_nil
        end
      
        it "should ignore symbol" do  
          Dataset.collapse(:invalid).attributes[:collapse].should be_nil
        end
      
      end
    
      context "given valid collapse" do
        it "should set daily" do
          Dataset.collapse(:daily).attributes[:collapse].should eq :daily
        end
        it "should set weekly" do
          Dataset.collapse(:weekly).attributes[:collapse].should eq :weekly
        end
        it "should set monthly" do
          Dataset.collapse(:monthly).attributes[:collapse].should eq :monthly
        end
        it "should set quarterly" do
          Dataset.collapse(:quarterly).attributes[:collapse].should eq :quarterly
        end
        it "should set annual" do
          Dataset.collapse(:annual).attributes[:collapse].should eq :annual
        end
      end
    
    end
  
    describe "trim_start" do
      
      context "given an invalid date" do
        
        it "should reject string" do
          Dataset.trim_start('0000-00-00').attributes[:trim_start].should eq nil
        end
      
        it "should reject invalid date" do
          Dataset.trim_start("").attributes[:trim_start].should eq nil
        end
    
        it "should reject invalid date" do
          Dataset.trim_start("asdf").attributes[:trim_start].should eq nil
        end
      
        it "should ignore invalid collapse" do
          Dataset.collapse('yearly').trim_start(Date.today.to_s).attributes[:trim_start].should eq Date.today.jd
        end
    
      end
      
      context "given valid date" do
      
        it "should accept date" do
          date = Date.today
          Dataset.trim_start(date).attributes[:trim_start].should eq Date.today.jd
        end

        it "should accept string date" do
          date = Date.today.to_s
          Dataset.trim_start(date).attributes[:trim_start].should eq Date.today.jd
        end

        it "should accept string julian date" do
          date = Date.today.jd.to_s
          Dataset.trim_start(date).attributes[:trim_start].should eq Date.today.jd
        end
      
        it "should accept integer" do
          date = Date.today.jd
          Dataset.trim_start(date).attributes[:trim_start].should eq Date.today.jd
        end
    
      end
      
    end
  
  end
end