# encoding: utf-8
require 'spec_helper'

describe Multiset do
  let(:d1){ create(:dataset, data: Quandl::Fabricate::Data::Table.rand( rows: 10, columns: 4, nils: false ) ) }
  let(:d2){ create(:dataset, data: Quandl::Fabricate::Data::Table.rand( rows: 10, columns: 4, nils: false ) ) }
  let(:multiset){ Multiset.find_existing('ephemeral') }
  subject{ multiset }
  
  describe "#data" do
    subject{ multiset.data.columns("#{d1.id}.1,#{d2.id}.2") }
    
    its(:count){ should eq 10 }
    its(:to_h){ should be_present }
    its(:to_a){ should be_present }
    
  end
  
  
  context "given ascending columns" do
    
    it "should return the expected column_ids" do
      subject.data.columns("#{d2.id.to_i}.1,#{d1.id.to_i}.1,#{d2.id.to_i}.3,#{d1.id.to_i}.2").to_a
      subject.column_ids.should eq [
        Dataset.find(d2.id).column_ids[0],
        Dataset.find(d1.id).column_ids[0],
        Dataset.find(d2.id).column_ids[2],
        Dataset.find(d1.id).column_ids[1],
      ]
    end

    it "should return the expected columns" do
      subject.data.columns("#{d2.id.to_i}.1,#{d1.id.to_i}.1,#{d2.id.to_i}.3,#{d1.id.to_i}.2")
      subject.data[0][1].should eq d2.data[0][1]
      subject.data[0][2].should eq d1.data[0][1]
      subject.data[0][3].should eq d2.data[0][3]
      subject.data[0][4].should eq d1.data[0][2]
    end
  
  end
  
  context "given descending columns" do
  
    it "should return the expected columns" do
      subject.data.columns("#{d1.id.to_i}.2,#{d1.id.to_i}.1")
      subject.data[0][1].should_not eq subject.data[0][2]
    end
    
  end
  
end